
#get the folder where this script file is located (this circumvents having to manually change the rootpath directory)
#and set it as the current directory
cd(@__DIR__)

using Pkg 


#activate the environment of all the packages needed to run the code
#this has to be run every time the script is run
#activate the project=environment in the current directory
Pkg.activate(".")
#this loads all the packages in the versions described in the project.toml and manifest.toml files. 
#see https://pkgdocs.julialang.org/v1/managing-packages/; only has to be run once to get the packages.
#Pkg.instantiate()



#=
these lines add (install) the packages needed by the script
have to be run only once; if you already have a manifest.toml and project.toml file, 
they already include the information of the following Pkg.add lines and it is enough to call Pkg.instantiate();
 if you do not have the toml files, running Pkg.add will add all the needed packages in their current versions; the 
=#
    #=
Pkg.add("Revise")
Pkg.add("Statistics")
Pkg.add("LinearAlgebra")
Pkg.add("Plots")
Pkg.add("Random")
=#

#load all the packages I need
using Revise, Plots, LinearAlgebra, Statistics, Random
using DelimitedFiles #to use writedlm



Random.seed!(1234)

n = 10000

φ = 0.8
φ = 1

b_0 = 0

e = randn(n + 1)
plot_e = plot(e,label = "e")
savefig(plot_e,"./e.pdf")

y = zeros(n + 1)


#plot the sum of errors, i.e. a random walk (if φ = 1)
for i in 1:n
    y[i+1] = b_0 + φ * y[i] + e[i+1] 
    #show(y[i+1])
end

plot_y = plot(y,label = "y")
display(plot_y)
savefig(plot_y,"./y.pdf")

index = [1:1:n+1;]

#write a tab delimited file and save it in the folder data in the current directory
open("./yande.csv", "w") do io
   writedlm(io, [index y e])
end

include("subscript.jl")

function mysum(x)
    sumresult = 0.0
    for i in 1:size(x,1)
        sumresult = x[i]
    end
return sumresult
end

ysum = mysum(y)

